# ltlcross runner
Python wrapper around the amazing tool `ltlcross` from [Spot](https://spot.lrde.epita.fr/) library for omega automata and LTL.

## Requires
* [Spot](https://spot.lrde.epita.fr/)
* Python >= 3.6

The following libraries are needed for bokeh scatter plots (can be used in Jupyter)
* [bokeh](https://bokeh.org/) (installs automatically by `pip`)
* [colorcet](https://colorcet.holoviz.org/) (installs automatically by `pip`)
* [jupyter_bokeh](https://github.com/bokeh/jupyter_bokeh) for rendering the plots in JupyterLab

## Installation
```
python3 -m pip install -U ltlcross-runner
```